<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:D="DAV:"
                version="1.0">

  <xsl:param name="path"/>
  <xsl:param name="start"/>

  <xsl:template match="database">
    <D:multistatus>
      <xsl:choose>
        <!-- Specified part of the database. -->
        <xsl:when test="$start != ''">
          <!-- Emit the container. -->
          <xsl:call-template name="resource">
            <xsl:with-param name="element" select="//*[local-name() = $start][1]"/>
            <xsl:with-param name="container">true</xsl:with-param>
          </xsl:call-template>
          <!-- Emit all resources. -->
          <xsl:for-each select="//*[local-name() = $start]/*">
            <xsl:call-template name="resource">
              <xsl:with-param name="element" select="."/>
            </xsl:call-template>
          </xsl:for-each>
        </xsl:when>
        <!-- Top level. -->
        <xsl:otherwise>
          <!-- Emit the container. -->
          <xsl:call-template name="resource">
            <xsl:with-param name="element" select="."/>
            <xsl:with-param name="container">true</xsl:with-param>
          </xsl:call-template>
          <!-- Emit all resources. -->
          <xsl:for-each select="*">
            <xsl:call-template name="resource">
              <xsl:with-param name="element" select="."/>
            </xsl:call-template>
          </xsl:for-each>
        </xsl:otherwise>
      </xsl:choose>
    </D:multistatus>
  </xsl:template>

  <xsl:template name="resource">
    <xsl:param name="element"/>
    <xsl:param name="container"/>
    <D:response>
      <xsl:choose>
        <xsl:when test="$container != ''">
          <D:href><xsl:value-of select="$path"/>/</D:href>
        </xsl:when>
        <xsl:otherwise>
          <D:href><xsl:value-of select="$path"/>/<xsl:value-of select="local-name()"/><xsl:if test="count($element/*) != 0">/</xsl:if></D:href>
        </xsl:otherwise>
      </xsl:choose>
      <D:propstat>
        <D:prop>
          <D:creationdate>2004-10-13T23:57:00Z</D:creationdate>
          <xsl:choose>
            <xsl:when test="$container != ''">
              <D:displayname><xsl:value-of select="$path"/></D:displayname>
            </xsl:when>
            <xsl:otherwise>
              <D:displayname><xsl:value-of select="local-name()"/></D:displayname>
            </xsl:otherwise>
          </xsl:choose>
          <D:resourcetype>
          <xsl:if test="count($element/*) != 0">
            <D:collection/>
          </xsl:if>
          </D:resourcetype>
          <xsl:if test="count($element/*) = 0">
            <D:getcontenttype>text/html</D:getcontenttype>
          </xsl:if>
        </D:prop>
        <D:status>HTTP/1.1 200 OK</D:status>
      </D:propstat>
    </D:response>
  </xsl:template>

</xsl:stylesheet>
